ExpandableFabMenu class

Builds the Boom Menu

Inheritance

Constructors

ExpandableFabMenu({Key? key, List<ExpandableFabMenuItem> children = const [], bool scrollVisible = true, String? title, String? subtitle, required Color backgroundColor, Color? titleColor, Color? subTitleColor, Color? foregroundColor, double elevation = 6.0, double overlayOpacity = 0.8, Color overlayColor = Colors.white, AnimatedIconData? animatedIcon, IconThemeData? animatedIconTheme, required Widget? child, double marginBottom = 0, double marginLeft = 16, double marginRight = 0, VoidCallback? onOpen, VoidCallback? onClose, bool overlayVisible = false, ShapeBorder fabMenuBorder = const CircleBorder(), Alignment fabAlignment = Alignment.centerRight, double fabPaddingRight = 0, double fabPaddingLeft = 0, double fabPaddingTop = 0, VoidCallback? onPress, int animationSpeed = 150})
const

Properties

animatedIcon → AnimatedIconData?
The animated icon to show as the main button child. If this is provided the child is ignored.
final
animatedIconTheme → IconThemeData?
The theme for the animated icon.
final
animationSpeed → int
The speed of the animation
final
backgroundColor → Color
final
child → Widget?
The child of the main button, ignored if animatedIcon is non null.
final
children → List<ExpandableFabMenuItem>
Children buttons, from the lowest to the highest.
final
elevation → double
final
fabAlignment → Alignment
final
fabMenuBorder → ShapeBorder
final
fabPaddingLeft → double
final
fabPaddingRight → double
final
fabPaddingTop → double
final
foregroundColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
marginBottom → double
final
marginLeft → double
final
marginRight → double
final
onClose → VoidCallback?
Executed when the dial is closed.
final
onOpen → VoidCallback?
Executed when the dial is opened.
final
onPress → VoidCallback?
Executed when the dial is pressed. If given, the dial only opens on long press!
final
overlayColor → Color
The color of the background overlay.
final
overlayOpacity → double
The opacity of the background overlay when the dial is open.
final
overlayVisible → bool
If true user is forced to close dial manually by tapping main button. WARNING: If true, overlay is not rendered.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollVisible → bool
Used to get the button hidden on scroll. See examples for more info.
final
subtitle → String?
final
subTitleColor → Color?
final
title → String?
final
titleColor → Color?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ExpandableFabMenuState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited